"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.build = void 0;
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const path_1 = require("path");
const config_1 = require("../config");
const ora_1 = __importDefault(require("ora"));
function build() {
    const spinner = (0, ora_1.default)('Building functions').start();
    const functions = (0, fs_1.readdirSync)(config_1.config.functionsDir).filter((f) => f.endsWith('.ts'));
    (0, child_process_1.execSync)(`rm -rf ${config_1.config.buildDir}`);
    (0, child_process_1.execSync)(`mkdir ${config_1.config.buildDir}`);
    for (const functionFile of functions) {
        const functionName = functionFile.replace('.ts', '');
        spinner.text = `Building ${functionName}`;
        (0, child_process_1.execSync)(`npx tsc --module CommonJS ${(0, path_1.join)(config_1.config.functionsDir, functionFile)} --outDir ${(0, path_1.join)(config_1.config.buildDir, functionName)}`);
        (0, fs_1.writeFileSync)((0, path_1.join)(config_1.config.buildDir, functionName, 'package.json'), JSON.stringify({
            main: 'index.js',
            dependencies: JSON.parse((0, fs_1.readFileSync)('./package.json').toString())
                .dependencies,
        }));
        (0, fs_1.writeFileSync)((0, path_1.join)(config_1.config.buildDir, functionName, 'index.js'), `exports.${functionName} = require('./${(0, path_1.join)(config_1.config.functionsDir, functionName)}').${functionName};`);
    }
    spinner.succeed('Built functions');
}
exports.build = build;
//# sourceMappingURL=build.js.map